package com.example.kantinku

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.items
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.Remove
import androidx.compose.material.icons.filled.ShoppingCart
import androidx.compose.material.icons.filled.Delete
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            Surface(
                modifier = Modifier.fillMaxSize(),
                color = Color(0xFFFFD700)
            ) {
                FoodOrderingApp()
            }
        }
    }
}

data class Warung(
    val id: String,
    val name: String,
    val description: String,
    val imageResId: Int
)

data class FoodItem(
    val id: String,
    val warungId: String,
    val name: String,
    val description: String,
    val price: Double,
    val imageResId: Int
)

data class CartItem(
    val foodItem: FoodItem,
    var quantity: Int = 1
)

sealed class Screen {
    object WarungList : Screen()
    data class MenuList(val warung: Warung) : Screen()
    object Cart : Screen()
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun FoodOrderingApp() {
    var currentScreen by remember { mutableStateOf<Screen>(Screen.WarungList) }
    var selectedWarung by remember { mutableStateOf<Warung?>(null) }
    var cart by remember { mutableStateOf(mutableListOf<CartItem>()) }

    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Text(
                        when (currentScreen) {
                            is Screen.WarungList -> "KantinKu"
                            is Screen.MenuList -> "Menu ${selectedWarung?.name}"
                            Screen.Cart -> "Keranjang"
                        }
                    )
                },
                navigationIcon = {
                    if (currentScreen !is Screen.WarungList) {
                        IconButton(onClick = {
                            currentScreen = when (currentScreen) {
                                is Screen.MenuList -> Screen.WarungList
                                is Screen.Cart -> {
                                    if (selectedWarung != null) Screen.MenuList(selectedWarung!!)
                                    else Screen.WarungList
                                }
                                else -> Screen.WarungList
                            }
                        }) {
                            Icon(Icons.Default.ArrowBack, "Kembali")
                        }
                    }
                },
                actions = {
                    if (currentScreen !is Screen.Cart) {
                        IconButton(onClick = { currentScreen = Screen.Cart }) {
                            BadgedBox(
                                badge = {
                                    if (cart.isNotEmpty()) {
                                        Badge { Text(cart.size.toString()) }
                                    }
                                }
                            ) {
                                Icon(Icons.Default.ShoppingCart, "Keranjang")
                            }
                        }
                    }
                }
            )
        }
    ) { paddingValues ->
        Box(modifier = Modifier.padding(paddingValues)) {
            when (val screen = currentScreen) {
                is Screen.WarungList -> WarungList(
                    onWarungSelected = { warung ->
                        selectedWarung = warung
                        currentScreen = Screen.MenuList(warung)
                    }
                )
                is Screen.MenuList -> FoodList(
                    warung = screen.warung,
                    cart = cart,
                    onAddToCart = { foodItem, quantity ->
                        val existingItem = cart.find { it.foodItem.id == foodItem.id }
                        if (existingItem != null) {
                            existingItem.quantity += quantity
                            cart = ArrayList(cart)
                        } else {
                            cart.add(CartItem(foodItem, quantity))
                            cart = ArrayList(cart)
                        }
                    }
                )
                Screen.Cart -> CartScreen(
                    cart = cart,
                    onRemoveItem = { cartItem ->
                        cart.remove(cartItem)
                        cart = ArrayList(cart)
                    },
                    onUpdateQuantity = { cartItem, newQuantity ->
                        if (newQuantity > 0) {
                            cartItem.quantity = newQuantity
                            cart = ArrayList(cart)
                        } else {
                            cart.remove(cartItem)
                            cart = ArrayList(cart)
                        }
                    },
                    onCheckout = {
                        cart.clear()
                        cart = ArrayList(cart)
                        currentScreen = Screen.WarungList
                    }
                )
            }
        }
    }
}

@Composable
fun WarungList(onWarungSelected: (Warung) -> Unit) {
    val warungs = listOf(
        Warung("w1", "Warung Pak Budi", "Masakan Tradisional", R.drawable.warung1),
        Warung("w2", "Warung Makan Siti", "Spesialis Masakan Jawa", R.drawable.warung2),
        Warung("w3", "Warung Seafood Mas John", "Ikan Segar Setiap Hari", R.drawable.warung3)
    )

    LazyVerticalGrid(
        columns = GridCells.Fixed(2),
        contentPadding = PaddingValues(8.dp)
    ) {
        items(warungs) { warung ->
            Card(
                modifier = Modifier
                    .padding(8.dp)
                    .clickable { onWarungSelected(warung) },
                shape = RoundedCornerShape(8.dp)
            ) {
                Column(
                    horizontalAlignment = Alignment.CenterHorizontally,
                    modifier = Modifier.padding(16.dp)
                ) {
                    Image(
                        painter = painterResource(id = warung.imageResId),
                        contentDescription = warung.name,
                        modifier = Modifier
                            .size(120.dp)
                            .aspectRatio(1f),
                        contentScale = ContentScale.Crop
                    )
                    Spacer(modifier = Modifier.height(8.dp))
                    Text(
                        text = warung.name,
                        fontWeight = FontWeight.Bold,
                        fontSize = 16.sp
                    )
                    Text(
                        text = warung.description,
                        color = Color.Gray,
                        fontSize = 12.sp
                    )
                }
            }
        }
    }
}

@Composable
fun FoodList(
    warung: Warung,
    cart: List<CartItem>,
    onAddToCart: (FoodItem, Int) -> Unit
) {
    var searchQuery by remember { mutableStateOf("") }
    var showDialog by remember { mutableStateOf(false) }
    var selectedFood by remember { mutableStateOf<FoodItem?>(null) }

    val foodItems = when (warung.id) {
        "w1" -> listOf(
            FoodItem("f1", "w1", "Nasi Goreng", "Klasik dan Lezat", 15000.0, R.drawable.food1),
            FoodItem("f2", "w1", "Sate Ayam", "Sate Tradisional", 25000.0, R.drawable.food2),
            FoodItem("f3", "w1", "Gado-gado", "Sayur Segar", 20000.0, R.drawable.food3)
        )
        "w2" -> listOf(
            FoodItem("f4", "w2", "Soto Ayam", "Kuah Khas Jawa", 18000.0, R.drawable.food4),
            FoodItem("f5", "w2", "Bakso", "Bakso Kenyal", 15000.0, R.drawable.food5),
            FoodItem("f6", "w2", "Pecel", "Sayur Dengan Bumbu Kacang", 22000.0, R.drawable.food6)
        )
        "w3" -> listOf(
            FoodItem("f7", "w3", "Udang Goreng", "Udang Segar Crispy", 45000.0, R.drawable.food7),
            FoodItem("f8", "w3", "Ikan Bakar", "Ikan Bakar Bumbu Merah", 35000.0, R.drawable.food8),
            FoodItem("f9", "w3", "Kepiting Saus Padang", "Pedas Menggugah Selera", 60000.0, R.drawable.food9)
        )
        else -> emptyList()
    }

    val filteredFoodItems = foodItems.filter {
        it.name.contains(searchQuery, ignoreCase = true)
    }

    Column(modifier = Modifier.fillMaxSize()) {
        TextField(
            value = searchQuery,
            onValueChange = { searchQuery = it },
            label = { Text("Cari Menu...") },
            modifier = Modifier
                .padding(8.dp)
                .fillMaxWidth(),
            singleLine = true
        )

        if (filteredFoodItems.isEmpty()) {
            Text(
                text = "Tidak ada item yang cocok",
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(16.dp),
                color = Color.Gray,
                fontSize = 16.sp,
                textAlign = TextAlign.Center
            )
        } else {
            LazyColumn(modifier = Modifier.fillMaxSize()) {
                items(filteredFoodItems) { foodItem ->
                    FoodCard(
                        foodItem = foodItem,
                        onAddToCart = {
                            selectedFood = foodItem
                            showDialog = true
                        }
                    )
                }
            }
        }
    }

    if (showDialog && selectedFood != null) {
        QuantityDialog(
            foodItem = selectedFood!!,
            onDismiss = { showDialog = false },
            onConfirm = { quantity ->
                onAddToCart(selectedFood!!, quantity)
                showDialog = false
            }
        )
    }
}

@Composable
fun FoodCard(foodItem: FoodItem, onAddToCart: () -> Unit) {
    Card(
        shape = RoundedCornerShape(8.dp),
        modifier = Modifier
            .padding(8.dp)
            .fillMaxWidth()
    ) {
        Row(modifier = Modifier.fillMaxWidth()) {
            Image(
                painter = painterResource(id = foodItem.imageResId),
                contentDescription = foodItem.name,
                contentScale = ContentScale.Crop,
                modifier = Modifier.size(100.dp)
            )

            Column(
                modifier = Modifier
                    .padding(16.dp)
                    .weight(1f)
            ) {
                Text(text = foodItem.name, fontWeight = FontWeight.Bold, fontSize = 18.sp)
                Text(text = foodItem.description, fontSize = 14.sp, color = Color.Gray)
                Text(
                    text = "Rp ${String.format("%,d", foodItem.price.toInt())}",
                    fontWeight = FontWeight.Bold,
                    fontSize = 16.sp,
                    color = Color(0xFF4CAF50)
                )
            }

            Button(
                onClick = onAddToCart,
                modifier = Modifier.padding(16.dp),
                colors = ButtonDefaults.buttonColors(containerColor = Color(0xFF4CAF50))
            ) {
                Text("Tambah")
            }
        }
    }
}

@Composable
fun QuantityDialog(
    foodItem: FoodItem,
    onDismiss: () -> Unit,
    onConfirm: (Int) -> Unit
) {
    var quantity by remember { mutableStateOf(1) }

    AlertDialog(
        onDismissRequest = onDismiss,
        title = { Text("Pilih Jumlah") },
        text = {
            Column {
                Text(foodItem.name, fontWeight = FontWeight.Bold)
                Spacer(modifier = Modifier.height(8.dp))
                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    horizontalArrangement = Arrangement.SpaceBetween,
                    modifier = Modifier.fillMaxWidth()
                ) {
                    IconButton(onClick = { if (quantity > 1) quantity-- }) {
                        Icon(Icons.Default.Remove, "Kurangi")
                    }
                    Text(
                        text = quantity.toString(),
                        fontSize = 18.sp,
                        fontWeight = FontWeight.Bold
                    )
                    IconButton(onClick = { quantity++ }) {
                        Icon(Icons.Default.Add, "Tambah")
                    }
                }
            }
        },
        confirmButton = {
            TextButton(onClick = { onConfirm(quantity) }) {
                Text("Tambah")
            }
        },
        dismissButton = {
            TextButton(onClick = onDismiss) {
                Text("Batal")
            }
        }
    )
}

@Composable
fun CartScreen(
    cart: List<CartItem>,
    onRemoveItem: (CartItem) -> Unit,
    onUpdateQuantity: (CartItem, Int) -> Unit,
    onCheckout: () -> Unit
) {
    Column(modifier = Modifier.fillMaxSize()) {
        LazyColumn(
            modifier = Modifier
                .weight(1f)
                .padding(8.dp)
        ) {
            items(cart) { cartItem ->
                Card(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(8.dp)
                ) {
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(16.dp),
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        Column(modifier = Modifier.weight(1f)) {
                            Text(
                                text = cartItem.foodItem.name,
                                fontWeight = FontWeight.Bold,
                                fontSize = 16.sp
                            )
                            Text(
                                text = "Rp ${String.format("%,d", (cartItem.foodItem.price * cartItem.quantity).toInt())}",
                                color = Color.Gray
                            )
                            Row(
                                verticalAlignment = Alignment.CenterVertically,
                                modifier = Modifier.padding(top = 8.dp)
                            ) {
                                IconButton(
                                    onClick = { onUpdateQuantity(cartItem, cartItem.quantity - 1) }
                                ) {
                                    Icon(Icons.Default.Remove, "Kurangi")
                                }
                                Text(
                                    text = cartItem.quantity.toString(),
                                    modifier = Modifier.padding(horizontal = 8.dp),
                                    fontWeight = FontWeight.Bold
                                )
                                IconButton(
                                    onClick = { onUpdateQuantity(cartItem, cartItem.quantity + 1) }
                                ) {
                                    Icon(Icons.Default.Add, "Tambah")
                                }
                            }
                        }
                        IconButton(
                            onClick = { onRemoveItem(cartItem) }
                        ) {
                            Icon(Icons.Default.Delete, "Hapus")
                        }
                    }
                }
            }
        }

        Card(
            modifier = Modifier
                .fillMaxWidth()
                .padding(8.dp)
        ) {
            Column(
                modifier = Modifier.padding(16.dp)
            ) {
                Row(
                    modifier = Modifier.fillMaxWidth(),
                    horizontalArrangement = Arrangement.SpaceBetween
                ) {
                    Text(
                        text = "Total Pembayaran",
                        fontWeight = FontWeight.Bold,
                        fontSize = 18.sp
                    )
                    Text(
                        text = "Rp ${String.format("%,d", cart.sumOf { (it.foodItem.price * it.quantity).toInt() })}",
                        fontWeight = FontWeight.Bold,
                        fontSize = 18.sp,
                        color = Color(0xFF4CAF50)
                    )
                }

                Button(
                    onClick = onCheckout,
                    enabled = cart.isNotEmpty(),
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(top = 16.dp),
                    colors = ButtonDefaults.buttonColors(
                        containerColor = Color(0xFF4CAF50),
                        disabledContainerColor = Color.Gray
                    )
                ) {
                    Text(
                        text = "Checkout",
                        color = Color.White,
                        modifier = Modifier.padding(vertical = 4.dp)
                    )
                }
            }
        }
    }
}

object R {
    object drawable {
        const val warung1 = android.R.drawable.ic_menu_report_image
        const val warung2 = android.R.drawable.ic_menu_report_image
        const val warung3 = android.R.drawable.ic_menu_report_image
        const val food1 = android.R.drawable.ic_menu_report_image
        const val food2 = android.R.drawable.ic_menu_report_image
        const val food3 = android.R.drawable.ic_menu_report_image
        const val food4 = android.R.drawable.ic_menu_report_image
        const val food5 = android.R.drawable.ic_menu_report_image
        const val food6 = android.R.drawable.ic_menu_report_image
        const val food7 = android.R.drawable.ic_menu_report_image
        const val food8 = android.R.drawable.ic_menu_report_image
        const val food9 = android.R.drawable.ic_menu_report_image
    }
}